← Back to team overview

launchpad-reviewers team mailing list archive

[Merge] ~jugmac00/launchpad:update-wadl-for-inclusive-naming into launchpad:master

 

Jürgen Gmach has proposed merging ~jugmac00/launchpad:update-wadl-for-inclusive-naming into launchpad:master.

Commit message:
Update API for inclusive naming

Requested reviews:
  Launchpad code reviewers (launchpad-reviewers)

For more details, see:
https://code.launchpad.net/~jugmac00/launchpad/+git/launchpad/+merge/411788
-- 
Your team Launchpad code reviewers is requested to review the proposed merge of ~jugmac00/launchpad:update-wadl-for-inclusive-naming into launchpad:master.
diff --git a/lib/lp/_schema_circular_imports.py b/lib/lp/_schema_circular_imports.py
index 204fa61..af21a01 100644
--- a/lib/lp/_schema_circular_imports.py
+++ b/lib/lp/_schema_circular_imports.py
@@ -884,8 +884,8 @@ patch_operations_explicit_version(
 # IDistroSeriesDifference
 patch_entry_explicit_version(IDistroSeriesDifference, 'beta')
 patch_operations_explicit_version(
-    IDistroSeriesDifference, 'beta', "addComment", "blacklist",
-    "requestPackageDiffs", "unblacklist")
+    IDistroSeriesDifference, 'beta', "addComment", "blocklist",
+    "requestPackageDiffs", "unblocklist")
 
 # IDistroSeriesDifferenceComment
 patch_entry_explicit_version(IDistroSeriesDifferenceComment, 'beta')
diff --git a/lib/lp/buildmaster/doc/builder.txt b/lib/lp/buildmaster/doc/builder.txt
index af1c423..7671c5b 100644
--- a/lib/lp/buildmaster/doc/builder.txt
+++ b/lib/lp/buildmaster/doc/builder.txt
@@ -7,7 +7,7 @@ re-written and unit tests moved to buildmaster/tests/test_builder.py
 Builder Class
 =============
 
-The Builder class represents a slave machine in the build farm. These
+The Builder class represents a worker machine in the build farm. These
 slaves are used to execute untrusted code -- for example when building
 packages.
 
diff --git a/lib/lp/registry/enums.py b/lib/lp/registry/enums.py
index 699149d..d150e02 100644
--- a/lib/lp/registry/enums.py
+++ b/lib/lp/registry/enums.py
@@ -292,14 +292,14 @@ class DistroSeriesDifferenceStatus(DBEnumeratedType):
         """)
 
     BLACKLISTED_CURRENT = DBItem(2, """
-        Blacklisted current version
+        Blocklisted current version
 
         This difference is being ignored until a new package is uploaded
         or the status is manually updated.
         """)
 
     BLACKLISTED_ALWAYS = DBItem(3, """
-        Blacklisted always
+        Blocklisted always
 
         This difference should always be ignored.
         """)
diff --git a/lib/lp/registry/javascript/tests/test_distroseriesdifferences_details.js b/lib/lp/registry/javascript/tests/test_distroseriesdifferences_details.js
index 682470d..21c174b 100644
--- a/lib/lp/registry/javascript/tests/test_distroseriesdifferences_details.js
+++ b/lib/lp/registry/javascript/tests/test_distroseriesdifferences_details.js
@@ -353,7 +353,7 @@ YUI.add('lp.registry.distroseriesdifferences_details.test', function (Y) {
             overlay.form_node.one('button[type="submit"]').simulate('click');
 
             Y.Assert.isTrue(event_fired);
-            Y.Assert.areEqual('unblacklist', method);
+            Y.Assert.areEqual('unblocklist', method);
             Y.Assert.areEqual(false, all);
             Y.Assert.areEqual('Test comment', comment);
             Y.Assert.areEqual(input, target);
@@ -377,7 +377,7 @@ YUI.add('lp.registry.distroseriesdifferences_details.test', function (Y) {
             this.widget.on("blacklist_changed", handleEvent, this.widget);
             overlay.form_node.one('button[type="submit"]').simulate('click');
 
-            Y.Assert.areEqual('blacklist', method);
+            Y.Assert.areEqual('blocklist', method);
             Y.Assert.areEqual(true, all);
             Y.Assert.areEqual(input, target);
         },
@@ -400,7 +400,7 @@ YUI.add('lp.registry.distroseriesdifferences_details.test', function (Y) {
             this.widget.on("blacklist_changed", handleEvent, this.widget);
             overlay.form_node.one('button[type="submit"]').simulate('click');
 
-            Y.Assert.areEqual('blacklist', method);
+            Y.Assert.areEqual('blocklist', method);
             Y.Assert.areEqual(false, all);
             Y.Assert.areEqual(input, target);
         },
@@ -411,7 +411,7 @@ YUI.add('lp.registry.distroseriesdifferences_details.test', function (Y) {
             var input = Y.one(
                 'div.blacklist-options input[value="BLACKLISTED_CURRENT"]');
             this.widget.blacklist_submit_handler(
-                'blacklist', false, "Test comment", input);
+                'blocklist', false, "Test comment", input);
         },
 
         test_blacklist_submit_handler_blacklist_simple: function() {
@@ -423,7 +423,7 @@ YUI.add('lp.registry.distroseriesdifferences_details.test', function (Y) {
             this.widget.commentWidget = mockCommentWidget;
 
             this.patchNamedPost(
-                'blacklist',
+                'blocklist',
                 {comment: 'Test comment', all: false});
             var input = Y.one(
                 'div.blacklist-options input[value="BLACKLISTED_CURRENT"]');
@@ -438,7 +438,7 @@ YUI.add('lp.registry.distroseriesdifferences_details.test', function (Y) {
             };
             this.widget.on('blacklisting_animation_ended', listener);
             this.widget.blacklist_submit_handler(
-                'blacklist', false, "Test comment", input);
+                'blocklist', false, "Test comment", input);
 
             Y.Assert.isTrue(input.get('checked'));
 
@@ -457,7 +457,7 @@ YUI.add('lp.registry.distroseriesdifferences_details.test', function (Y) {
             this.widget.commentWidget = mockCommentWidget;
 
             this.patchNamedPost(
-                'blacklist',
+                'blocklist',
                 {comment: 'Test comment', all: true});
             var input = Y.one(
                 'div.blacklist-options input[value="BLACKLISTED_CURRENT"]');
@@ -472,7 +472,7 @@ YUI.add('lp.registry.distroseriesdifferences_details.test', function (Y) {
             };
             this.widget.on('blacklisting_animation_ended', listener);
             this.widget.blacklist_submit_handler(
-                'blacklist', true, "Test comment", input);
+                'blocklist', true, "Test comment", input);
 
             Y.Assert.isTrue(input.get('checked'));
 
@@ -482,7 +482,7 @@ YUI.add('lp.registry.distroseriesdifferences_details.test', function (Y) {
             }, 1000);
         },
 
-        test_blacklist_submit_handler_unblacklist: function() {
+        test_blocklist_submit_handler_unblocklist: function() {
             var fired = false;
             var mockCommentWidget = Y.Mock();
             Y.Mock.expect(mockCommentWidget, {
@@ -492,7 +492,7 @@ YUI.add('lp.registry.distroseriesdifferences_details.test', function (Y) {
             this.widget.commentWidget = mockCommentWidget;
 
             this.patchNamedPost(
-                'unblacklist', {
+                'unblocklist', {
                     comment: 'Test comment',
                     all: true
             });
@@ -506,7 +506,7 @@ YUI.add('lp.registry.distroseriesdifferences_details.test', function (Y) {
 
             this.widget.on('blacklisting_animation_ended', listener);
             this.widget.blacklist_submit_handler(
-                'unblacklist', true, "Test comment", input);
+                'unblocklist', true, "Test comment", input);
 
             Y.Assert.isTrue(input.get('checked'));
             this.wait(function () {
@@ -525,7 +525,7 @@ YUI.add('lp.registry.distroseriesdifferences_details.test', function (Y) {
             var input = Y.one('div.blacklist-options input');
             input.set('checked', false);
             this.widget.blacklist_submit_handler(
-                null, 'unblacklist', true, "Test comment", input);
+                null, 'unblocklist', true, "Test comment", input);
         }
     }));
 
diff --git a/lib/lp/registry/model/distroseriesdifference.py b/lib/lp/registry/model/distroseriesdifference.py
index 3d3c55b..b68df3f 100644
--- a/lib/lp/registry/model/distroseriesdifference.py
+++ b/lib/lp/registry/model/distroseriesdifference.py
@@ -882,7 +882,7 @@ class DistroSeriesDifference(StormBase):
         return get_comment_with_status_change(
             self.status, new_status, comment)
 
-    def blacklist(self, commenter, all=False, comment=None):
+    def blocklist(self, commenter, all=False, comment=None):
         """See `IDistroSeriesDifference`."""
         if all:
             new_status = DistroSeriesDifferenceStatus.BLACKLISTED_ALWAYS
@@ -893,7 +893,7 @@ class DistroSeriesDifference(StormBase):
         self.status = new_status
         return dsd_comment
 
-    def unblacklist(self, commenter, comment=None):
+    def unblocklist(self, commenter, comment=None):
         """See `IDistroSeriesDifference`."""
         new_status = DistroSeriesDifferenceStatus.NEEDS_ATTENTION
         new_comment = self._getCommentWithStatusChange(new_status, comment)
diff --git a/lib/lp/registry/tests/test_distroseriesdifference.py b/lib/lp/registry/tests/test_distroseriesdifference.py
index 9ab7cae..0163383 100644
--- a/lib/lp/registry/tests/test_distroseriesdifference.py
+++ b/lib/lp/registry/tests/test_distroseriesdifference.py
@@ -448,57 +448,57 @@ class DistroSeriesDifferenceTestCase(TestCaseWithFactory):
             sorted([packageset.name for packageset in packagesets]),
             [packageset.name for packageset in ds_diff.packagesets])
 
-    def test_blacklist_unauthorised(self):
+    def test_blocklist_unauthorised(self):
         # If you're not an archive admin, you don't get to blacklist or
-        # unblacklist.
+        # unblocklist.
         ds_diff = self.factory.makeDistroSeriesDifference()
         random_joe = self.factory.makePerson()
         with person_logged_in(random_joe):
-            self.assertRaises(Unauthorized, getattr, ds_diff, 'blacklist')
-            self.assertRaises(Unauthorized, getattr, ds_diff, 'unblacklist')
+            self.assertRaises(Unauthorized, getattr, ds_diff, 'blocklist')
+            self.assertRaises(Unauthorized, getattr, ds_diff, 'unblocklist')
 
-    def test_blacklist_default(self):
-        # By default the current version is blacklisted.
+    def test_blocklist_default(self):
+        # By default the current version is blocklisted.
         ds_diff = self.factory.makeDistroSeriesDifference()
         admin = self.factory.makeArchiveAdmin(
             ds_diff.derived_series.main_archive)
 
         with person_logged_in(admin):
-            ds_diff.blacklist(admin)
+            ds_diff.blocklist(admin)
 
         self.assertEqual(
             DistroSeriesDifferenceStatus.BLACKLISTED_CURRENT,
             ds_diff.status)
 
-    def test_blacklist_all(self):
-        # All versions are blacklisted with the all=True param.
+    def test_blocklist_all(self):
+        # All versions are blocklisted with the all=True param.
         ds_diff = self.factory.makeDistroSeriesDifference()
         admin = self.factory.makeArchiveAdmin(
             ds_diff.derived_series.main_archive)
 
         with person_logged_in(admin):
-            ds_diff.blacklist(admin, all=True)
+            ds_diff.blocklist(admin, all=True)
 
         self.assertEqual(
             DistroSeriesDifferenceStatus.BLACKLISTED_ALWAYS,
             ds_diff.status)
 
-    def test_unblacklist(self):
-        # Unblacklisting will return to NEEDS_ATTENTION by default.
+    def test_unblocklist(self):
+        # Unblocklisting will return to NEEDS_ATTENTION by default.
         ds_diff = self.factory.makeDistroSeriesDifference(
             status=DistroSeriesDifferenceStatus.BLACKLISTED_CURRENT)
         admin = self.factory.makeArchiveAdmin(
             ds_diff.derived_series.main_archive)
 
         with person_logged_in(admin):
-            ds_diff.unblacklist(admin)
+            ds_diff.unblocklist(admin)
 
         self.assertEqual(
             DistroSeriesDifferenceStatus.NEEDS_ATTENTION,
             ds_diff.status)
 
-    def test_unblacklist_resolved(self):
-        # Status is resolved when unblacklisting a now-resolved difference.
+    def test_unblocklist_resolved(self):
+        # Status is resolved when unblocklisting a now-resolved difference.
         ds_diff = self.factory.makeDistroSeriesDifference(
             versions={
                 'derived': '0.9',
@@ -514,7 +514,7 @@ class DistroSeriesDifferenceTestCase(TestCaseWithFactory):
         admin = self.factory.makeArchiveAdmin(
             ds_diff.derived_series.main_archive)
         with person_logged_in(admin):
-            ds_diff.unblacklist(admin)
+            ds_diff.unblocklist(admin)
 
         self.assertEqual(
             DistroSeriesDifferenceStatus.RESOLVED,
@@ -541,7 +541,7 @@ class DistroSeriesDifferenceTestCase(TestCaseWithFactory):
             comment_string,
             ds_diff.latest_comment.message.text_contents)
 
-    def test_unblacklist_creates_comment(self):
+    def test_unblocklist_creates_comment(self):
         old_status = DistroSeriesDifferenceStatus.BLACKLISTED_ALWAYS
         ds_diff = self.factory.makeDistroSeriesDifference(
             status=old_status,
@@ -549,7 +549,7 @@ class DistroSeriesDifferenceTestCase(TestCaseWithFactory):
         admin = self.factory.makeArchiveAdmin(
             ds_diff.derived_series.main_archive)
         with person_logged_in(admin):
-            dsd_comment = ds_diff.unblacklist(
+            dsd_comment = ds_diff.unblocklist(
                 admin, "Ok now")
         new_status = DistroSeriesDifferenceStatus.NEEDS_ATTENTION
         expected_comment = 'Ok now\n\nIgnored: %s => %s' % (
@@ -557,7 +557,7 @@ class DistroSeriesDifferenceTestCase(TestCaseWithFactory):
 
         self.assertDSDComment(ds_diff, dsd_comment, expected_comment)
 
-    def test_blacklist_creates_comment(self):
+    def test_blocklist_creates_comment(self):
         old_status = DistroSeriesDifferenceStatus.NEEDS_ATTENTION
         ds_diff = self.factory.makeDistroSeriesDifference(
             status=old_status,
@@ -565,7 +565,7 @@ class DistroSeriesDifferenceTestCase(TestCaseWithFactory):
         admin = self.factory.makeArchiveAdmin(
             ds_diff.derived_series.main_archive)
         with person_logged_in(admin):
-            dsd_comment = ds_diff.blacklist(
+            dsd_comment = ds_diff.blocklist(
                 admin, True, "Wait until version 2.1")
         new_status = DistroSeriesDifferenceStatus.BLACKLISTED_ALWAYS
         expected_comment = 'Wait until version 2.1\n\nIgnored: %s => %s' % (
diff --git a/lib/lp/soyuz/browser/livefs.py b/lib/lp/soyuz/browser/livefs.py
index 39eeb4b..1c7281e 100644
--- a/lib/lp/soyuz/browser/livefs.py
+++ b/lib/lp/soyuz/browser/livefs.py
@@ -196,7 +196,7 @@ class ILiveFSEditSchema(Interface):
         title=u'Live filesystem build metadata',
         description=(
             u'A JSON dictionary of data about the image.  Entries here will '
-             'be passed to the builder slave.'))
+             'be passed to the builder worker.'))
 
 
 class LiveFSMetadataValidatorMixin:
diff --git a/lib/lp/soyuz/interfaces/livefs.py b/lib/lp/soyuz/interfaces/livefs.py
index d64dfe6..466baa4 100644
--- a/lib/lp/soyuz/interfaces/livefs.py
+++ b/lib/lp/soyuz/interfaces/livefs.py
@@ -248,7 +248,7 @@ class ILiveFSEditableAttributes(IHasOwner):
     metadata = exported(Dict(
         title=_(
             "A dict of data about the image.  Entries here will be passed to "
-            "the builder slave."),
+            "the builder worker."),
         key_type=TextLine(), required=True, readonly=False))
 
 

Follow ups
diff --git a/lib/lp/buildmaster/interfaces/builder.py b/lib/lp/buildmaster/interfaces/builder.py
index acd1dfd..a43fb7e 100644
--- a/lib/lp/buildmaster/interfaces/builder.py
+++ b/lib/lp/buildmaster/interfaces/builder.py
@@ -101,7 +101,7 @@ class IBuilderModerateAttributes(Interface):
     manual = exported(Bool(
         title=_('Manual Mode'), required=False, default=False,
         description=_('The auto-build system does not dispatch '
-                      'jobs automatically for slaves in manual mode.')))
+                      'jobs automatically for worker in manual mode.')))
 
     builderok = exported(Bool(
         title=_('Builder State OK'), required=True, default=True,
@@ -149,12 +149,12 @@ class IBuilderView(IHasBuildRecords, IHasOwner):
 
     name = exported(TextLine(
         title=_('Name'), required=True, constraint=name_validator,
-        description=_('Builder Slave Name used for reference purposes')))
+        description=_('Builder Worker Name used for reference purposes')))
 
     title = exported(Title(
         title=_('Title'), required=True,
         description=_(
-            'The builder slave title. Should be just a few words.')))
+            'The builder worker title. Should be just a few words.')))
 
     virtualized = exported(Bool(
         title=_('Virtualized'), required=True, default=False,
@@ -164,7 +164,7 @@ class IBuilderView(IHasBuildRecords, IHasOwner):
     vm_host = exported(TextLine(
         title=_('VM host'), required=False,
         description=_('The machine hostname hosting the virtual '
-                      'buildd-slave, e.g.: foobar-host.ppa')))
+                      'buildd-worker, e.g.: foobar-host.ppa')))
 
     vm_reset_protocol = exported(Choice(
         title=_("VM reset protocol"), vocabulary=BuilderResetProtocol,
@@ -189,12 +189,12 @@ class IBuilderView(IHasBuildRecords, IHasOwner):
 
     version = exported(Text(
         title=_('Version'), required=False,
-        description=_('The version of launchpad-buildd on the slave.')))
+        description=_('The version of launchpad-buildd on the worker.')))
 
     clean_status = exported(Choice(
         title=_("Clean status"), vocabulary=BuilderCleanStatus, readonly=True,
         description=_(
-            "The readiness of the slave to take a job. Only internal build "
+            "The readiness of the worker to take a job. Only internal build "
             "infrastructure bots need to or should write to this.")))
 
     date_clean_status_changed = exported(Datetime(
@@ -223,14 +223,14 @@ class IBuilderEdit(Interface):
 
 @exported_as_webservice_entry()
 class IBuilder(IBuilderEdit, IBuilderView, IBuilderModerateAttributes):
     """Build-slave information and state.
 
     Builder instance represents a single builder slave machine within the
     Launchpad Auto Build System. It should specify a 'processor' on which the
     machine is based and is able to build packages for; a URL, by which the
     machine is accessed through an XML-RPC interface; name, title for entity
     identification and browsing purposes; an LP-like owner which has
-    unrestricted access to the instance; the build slave machine status
+    unrestricted access to the instance; the build worker machine status
     representation, including the field/properties: virtualized, builderok,
     status, failnotes and currentjob.
     """
@@ -223,14 +223,14 @@ class IBuilderEdit(Interface):
 @exported_as_webservice_entry()
 class IBuilder(IBuilderEdit, IBuilderView, IBuilderModerateAttributes):
-    """Build-slave information and state.
+    """Build-worker information and state.
 
@@ -223,14 +223,14 @@ class IBuilderEdit(Interface):
 
-    Builder instance represents a single builder slave machine within the
+    Builder instance represents a single builder worker machine within the
     Launchpad Auto Build System. It should specify a 'processor' on which the
     machine is based and is able to build packages for; a URL, by which the
diff --git a/lib/lp/registry/browser/tests/test_distroseries.py b/lib/lp/registry/browser/tests/test_distroseries.py
index e1d1d66..e0d714e 100644
--- a/lib/lp/registry/browser/tests/test_distroseries.py
+++ b/lib/lp/registry/browser/tests/test_distroseries.py
@@ -1659,11 +1659,11 @@ class TestDistroSeriesLocalDifferences(TestCaseWithFactory,
         self.assertEqual('Invalid option', view.getFieldError('package_type'))
         self.assertContentEqual([], view.cached_differences.batch)
 
-    def test_batch_blacklisted_differences_with_higher_version(self):
+    def test_batch_blocklisted_differences_with_higher_version(self):
         # field.package_type parameter allows to list only
-        # blacklisted differences with a child's version higher than parent's.
-        derived_series, parent_series = self._createChildAndParent()
-        blacklisted_diff_higher = self.factory.makeDistroSeriesDifference(
+        # blocklisted differences with a child's version higher than parent's.
+        derived_series, _ = self._createChildAndParent()
+        blocklisted_diff_higher = self.factory.makeDistroSeriesDifference(
             derived_series=derived_series,
             status=DistroSeriesDifferenceStatus.BLACKLISTED_CURRENT,
             versions={'base': '1.1', 'parent': '1.3', 'derived': '1.10'})
@@ -1672,19 +1672,19 @@ class TestDistroSeriesLocalDifferences(TestCaseWithFactory,
             status=DistroSeriesDifferenceStatus.BLACKLISTED_CURRENT,
             versions={'base': '1.1', 'parent': '1.12', 'derived': '1.10'})
 
-        blacklisted_view = create_initialized_view(
+        blocklisted_view = create_initialized_view(
             derived_series,
             '+localpackagediffs',
             query_string='field.package_type=%s' % HIGHER_VERSION_THAN_PARENT)
-        unblacklisted_view = create_initialized_view(
+        unblocklisted_view = create_initialized_view(
             derived_series,
             '+localpackagediffs')
 
         self.assertContentEqual(
-            [blacklisted_diff_higher],
-            blacklisted_view.cached_differences.batch)
+            [blocklisted_diff_higher],
+            blocklisted_view.cached_differences.batch)
         self.assertContentEqual(
-            [], unblacklisted_view.cached_differences.batch)
+            [], unblocklisted_view.cached_differences.batch)
 
     def test_batch_resolved_differences(self):
         # Test that we can search for differences that we marked
diff --git a/lib/lp/registry/browser/tests/test_distroseriesdifference_webservice.py b/lib/lp/registry/browser/tests/test_distroseriesdifference_webservice.py
index 5e6a285..79a74d4 100644
--- a/lib/lp/registry/browser/tests/test_distroseriesdifference_webservice.py
+++ b/lib/lp/registry/browser/tests/test_distroseriesdifference_webservice.py
@@ -34,15 +34,15 @@ class DistroSeriesDifferenceWebServiceTestCase(TestCaseWithFactory):
         self.assertTrue(
             ws_diff.self_link.endswith(ds_diff_path))
 
-    def test_blacklist(self):
-        # The blacklist method can be called by people with admin access.
+    def test_blocklist(self):
+        # The blocklist method can be called by people with admin access.
         ds_diff = self.factory.makeDistroSeriesDifference()
         archive_admin = self.factory.makeArchiveAdmin(
             archive=ds_diff.derived_series.main_archive)
         ws_diff = ws_object(self.factory.makeLaunchpadService(
             archive_admin), ds_diff)
 
-        ws_diff.blacklist()
+        ws_diff.blocklist()
         transaction.commit()
 
         utility = getUtility(IDistroSeriesDifferenceSource)
@@ -53,8 +53,8 @@ class DistroSeriesDifferenceWebServiceTestCase(TestCaseWithFactory):
             DistroSeriesDifferenceStatus.BLACKLISTED_CURRENT,
             ds_diff.status)
 
-    def test_unblacklist(self):
-        # The unblacklist method can be called by people with admin access.
+    def test_unblocklist(self):
+        # The unblocklist method can be called by people with admin access.
         ds_diff = self.factory.makeDistroSeriesDifference(
             status=DistroSeriesDifferenceStatus.BLACKLISTED_CURRENT)
         archive_admin = self.factory.makeArchiveAdmin(
@@ -62,7 +62,7 @@ class DistroSeriesDifferenceWebServiceTestCase(TestCaseWithFactory):
         ws_diff = ws_object(self.factory.makeLaunchpadService(
             archive_admin), ds_diff)
 
-        ws_diff.unblacklist()
+        ws_diff.unblocklist()
         transaction.commit()
 
         utility = getUtility(IDistroSeriesDifferenceSource)
@@ -179,7 +179,7 @@ class DistroSeriesDifferenceWebServiceTestCase(TestCaseWithFactory):
         ws_diff = ws_object(self.factory.makeLaunchpadService(
             self.factory.makePerson()), ds_diff)
 
-        self.assertEqual(u'Blacklisted always', ws_diff.status)
+        self.assertEqual(u'Blocklisted always', ws_diff.status)
 
     def test_exported_sourcepackagename(self):
         # The difference's sourcepackagename is exposed.
diff --git a/lib/lp/registry/interfaces/distroseriesdifference.py b/lib/lp/registry/interfaces/distroseriesdifference.py
index c7a8b7f..2c4a8e7 100644
--- a/lib/lp/registry/interfaces/distroseriesdifference.py
+++ b/lib/lp/registry/interfaces/distroseriesdifference.py
@@ -252,14 +252,14 @@ class IDistroSeriesDifferenceAdmin(Interface):
         comment=TextLine(title=_('Comment text'), required=False),
         )
     @export_write_operation()
-    def blacklist(commenter, all=False, comment=None):
-        """Blacklist this version or all versions of this source package and
+    def blocklist(commenter, all=False, comment=None):
+        """Blocklists this version or all versions of this source package and
         adds a comment on this difference.
 
         :param commenter: The requestor `IPerson`.
         :param comment: The comment string.
         :param all: Indicates whether all versions of this package should
-            be blacklisted or just the current (default).
+            be blocklisted or just the current (default).
         :return: The created `DistroSeriesDifferenceComment` object.
         """
 
@@ -267,8 +267,8 @@ class IDistroSeriesDifferenceAdmin(Interface):
     @operation_parameters(
         comment=TextLine(title=_('Comment text'), required=False))
     @export_write_operation()
-    def unblacklist(commenter, comment=None):
-        """Removes this difference from the blacklist and adds a comment on
+    def unblocklist(commenter, comment=None):
+        """Removes this difference from the blocklist and adds a comment on
         this difference.
 
         The status will be updated based on the versions.
diff --git a/lib/lp/registry/javascript/distroseriesdifferences_details.js b/lib/lp/registry/javascript/distroseriesdifferences_details.js
index 2f4066c..f007fec 100644
--- a/lib/lp/registry/javascript/distroseriesdifferences_details.js
+++ b/lib/lp/registry/javascript/distroseriesdifferences_details.js
@@ -290,7 +290,7 @@ Y.extend(BlacklistWidget, Y.Widget, {
             // Figure out the new 'ignored' status.
             var value = target.get('value');
             var method_name = (value === 'NONE') ?
-                'unblacklist' : 'blacklist';
+                'unblocklist' : 'blocklist';
             var blacklist_all = (
                 target.get('value') === 'BLACKLISTED_ALWAYS');
             self.fire(
@@ -345,11 +345,11 @@ Y.extend(BlacklistWidget, Y.Widget, {
     ANIM_DURATION: 1,
 
     /**
      * Submit the blacklist or unblacklist action. Updates the comment
      * list if successful.
      *
      * @param method_name {String}
-     *     'blacklist' or 'unblacklist'.
+     *     'blocklist' or 'unblocklist'.
      * @param blacklist_all {Boolean}
      *     Is this a blacklist all versions or blacklist current (only
      *     relevant if method_name is 'blacklist').
@@ -376,7 +376,7 @@ Y.extend(BlacklistWidget, Y.Widget, {
                             from: { backgroundColor: '#FFFFFF'},
                             to: { backgroundColor: '#EEEEEE'},
                             duration: self.ANIM_DURATION,
-                            reverse: (method_name === 'unblacklist')
+                            reverse: (method_name === 'unblocklist')
                         });
                         fade_to_gray.on('end', function() {
                             self.fire('blacklisting_animation_ended');
@@ -345,11 +345,11 @@ Y.extend(BlacklistWidget, Y.Widget, {
 
     /**
-     * Submit the blacklist or unblacklist action. Updates the comment
+     * Submit the blocklist or unblocklist action. Updates the comment
      * list if successful.
      *